/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2006 - INRIA - Allan CORNET
 * Copyright (C) 2009 - DIGITEO - Allan CORNET
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */
#include "gw_core.h"
#include "stack-c.h"
/*--------------------------------------------------------------------------*/
int C2F(sci_type)(char *fname,unsigned long fname_len)
{
	int iType = 0;
	int l = 0, lc = 0;
	int one = 1;
	int zero = 0;

	CheckRhs(1,1);
	CheckLhs(1,2); 
	
	iType = GetType(1);
	if (! C2F(cremat)(fname, &Top, &zero, &one, &one, &l, &lc, fname_len)) return 0;
	*stk(l) = (double) iType;

	return 0;
}
/*--------------------------------------------------------------------------*/
